/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.util.activator.impl;

import static com.openexchange.util.custom.base.NullUtil.logger;
import java.io.Closeable;
import java.util.Deque;
import java.util.concurrent.LinkedBlockingDeque;
import org.osgi.util.tracker.ServiceTracker;
import org.slf4j.Logger;


/**
 * {@link ActivatorRegistryImpl}
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v7.8.2
 */
public final class ActivatorRegistryImpl implements Closeable, ActivatorRegistry {

    private static final Logger LOG = logger(ActivatorRegistryImpl.class);
    
    public final Deque<Registration> registrations;
    public final Deque<ServiceTracker<?, ?>> trackers;
    
    public ActivatorRegistryImpl() {
        this.registrations = new LinkedBlockingDeque<Registration>();
        this.trackers = new LinkedBlockingDeque<ServiceTracker<?, ?>>();
    }

    @Override
    public void close() {
        RegistrationTools.closeAll(registrations, LOG);
        RegistrationTools.closeAllReflectively(trackers, LOG);        
    }

    @Override
    public void add(Registration registration) {
        this.registrations.addLast(registration);
    }

    @Override
    public void add(ServiceTracker<?, ?> serviceTracker) {
        this.trackers.addLast(serviceTracker);
    }
    
}
